@@ -101,6 +101,14 @@ class SceneDto(IccBaseModel):
     power_requests: Optional[list[PowerRequestDto]]
 
 
+class DeviceDto(IccBaseModel):
+    name: str
+    room: str
+    ip: str
+    type: str
+    model: str
+
+
 """ Entitity Models """
 
 
@@ -120,12 +128,21 @@ class State(IccBaseModel):
 
 
 class SceneModel(IccBaseModel):
-    id: Optional[PydanticObjectId] = Field(None, alias="_id")
+    id: PydanticObjectId = Field(None, alias="_id")
     name: str
     lighting_requests: Optional[list[LightingRequestDto]]
     power_requests: Optional[list[PowerRequestDto]]
 
 
+class DeviceModel(IccBaseModel):
+    id: PydanticObjectId = Field(None, alias="_id")
+    name: str
+    room: str
+    ip: str
+    type: str
+    model: str
+
+
 """ IoT Devices Global Strings """
 
 
@@ -157,7 +174,7 @@ class ServiceUrls:
 
 
 class DeviceControllerProxy:
-    device_type_to_url = {
+    device_model_to_url = {
         LightingDeviceTypes.KasaBulb: ServiceUrls.KASA_BULB_CONTROLLER_URL,
         LightingDeviceTypes.KasaLedStrip: ServiceUrls.KASA_LED_STRIP_CONTROLLER_URL,
         PowerDeviceTypes.KasaPlug: ServiceUrls.KASA_PLUG_CONTROLLER_URL,
